; AutoIt Version: 3.0
; Language:       English
; Platform:       Win9x/NT
; Author:         Michael W. Bayley
;
; Script Function:
;   MultiRunCopy - MultiRun File Copy Utility
;

;
; Global values
;

; Title Information
$TitleBar = "MultiRun Copy Utility v1.0, (c) 2007 Michael W. Bayley"

; Program Values
$SourceFile = ""
$TargetFile = ""
$Option = 0
$Index = 0
$Msg = ""

$OverwriteOption = "/O"
$CreatePathOption = "/P"
$SilentOption = "/S"

$OverwriteFlag = 1
$CreatePathFlag = 8
$SilentFlag = 0


;
; Main Code
;
; Entry:		<None>
; Return:		0 - No errors
;			1 - Fatal error encountered
; Procedure:		1. If no parameters then display help.
;			2. If less than two parameters then error.
;			3. If more than five parameters then error.
;			4. Parse parameters.
;			5. Error if source does not exist.
;			6. Copy the file.
;			7. Report any errors.
;			8. Exit all done.

; 1. If no parameters then display help.
If $CmdLine[0] == 0 Then
	$Msg = "MultiRunCopy is a small utility to copy files without using the DOS prompt console." & @CRLF & @CRLF
	$Msg &= "Command line syntax is as follows:" & @CRLF & @CRLF
	$Msg &= "          MultiRunCopy.exe <SourceSpec> <TargetSpec> [" & $OverwriteOption & "] [" & $CreatePathOption & "] [" & $SilentOption & "]" & @CRLF & @CRLF
	$Msg &= "where the following apply:" & @CRLF & @CRLF
	$Msg &= "<SourceSpec>	Source file(s) spec (May include wildcards)" & @CRLF
	$Msg &= "<TargetSpec>	Target file(s) spec (May include wildcards)" & @CRLF
	$Msg &= $OverwriteOption & "		Overwrite target files option" & @CRLF
	$Msg &= $CreatePathOption & "		Create target path if needed option" & @CRLF
	$Msg &= $SilentOption & "		Silent option (Don't report copy errors)" & @CRLF & @CRLF
	MsgBox(0, $TitleBar, $Msg)
	Exit(0)


; 2. If less than two parameters then error.
ElseIf $CmdLine[0] < 2 Then
	MsgBox(0, $TitleBar, "Error - Too few parameters!")
	Exit(1)


; 3, If more than five parameters then error.
ElseIf $CmdLine[0] > 4 Then
	MsgBox(0, $TitleBar, "Error - Too many parameters!")
	Exit(1)
EndIf


; 4. Parse parameters.
$Source = $CmdLine[1]
If StringInStr($Source, "\") == 0 Then
	$Source = ".\" & $Source
EndIf

$Target = $CmdLine[2]
If StringInStr($Target, "\") == 0 Then
	$Target = ".\" & $Target
EndIf

For $Index = 3 to $CmdLine[0]
	If StringUpper($CmdLine[$Index]) == $OverwriteOption Then
		If BitAND($Option, $OverwriteFlag) Then
			MsgBox(0, $TitleBar, "Error - Multiple occurances of '" & $OverwriteOption & "' option!")
			Exit(1)
		EndIf
		$Option = BitOR($Option, $OverwriteFlag)
	ElseIf StringUpper($CmdLine[$Index]) == $CreatePathOption Then
		If BitAND($Option, $CreatePathFlag) Then
			MsgBox(0, $TitleBar, "Error - Multiple occurances of '" & $CreatePathOption & "' option!")
			Exit(1)
		EndIf
		$Option = BitOR($Option, $CreatePathFlag)
	ElseIf StringUpper($CmdLine[$Index]) == $SilentOption Then
		If $SilentFlag) Then
			MsgBox(0, $TitleBar, "Error - Multiple occurances of '" & $SilentOption & "' option!")
			Exit(1)
		EndIf
		$SilentFlag = 1
	Else
		MsgBox(0, $TitleBar, "Error - Unknown option '" & $CmdLine[$Index] & "'!")
		Exit(1)
	EndIf
Next


; 5. Error if source does not exist.
If FileExists($Source) <> 1 Then
	If $SilentFlag == 0 Then
		MsgBox(0, $TitleBar, "Error - Source file '" & $Source & "' does not exist!")
	EndIf
	Exit(1)
EndIf


; 6. Copy the file.
If FileCopy($Source, $Target, $Option) <> 1 Then
	; 7. Report any errors.
	If $SilentFlag == 0 Then
		MsgBox(0, $TitleBar, "Error - Copy of file '" & $Source & "' failed!")
	EndIf
	Return(1)
EndIf


; 8. Exit all done.
Exit(0)

